labeltools.label_leaves_in_expr_with_melodic_diatonic_intervals
===============================================================

.. autofunction:: abjad.tools.labeltools.label_leaves_in_expr_with_melodic_diatonic_intervals.label_leaves_in_expr_with_melodic_diatonic_intervals
   :noindex:
